@@ -17,6 +17,7 @@ else:
 
 failsonjython = pytest.mark.xfail("sys.platform.startswith('java')")
 
+
 def test_source_str_function():
     x = Source("3")
     assert str(x) == "3"
@@ -34,6 +35,7 @@ def test_source_str_function():
     """, rstrip=True)
     assert str(x) == "\n3"
 
+
 def test_unicode():
     try:
         unicode
@@ -45,10 +47,12 @@ def test_unicode():
     val = eval(co)
     assert isinstance(val, unicode)
 
+
 def test_source_from_function():
     source = _pytest._code.Source(test_source_str_function)
     assert str(source).startswith('def test_source_str_function():')
 
+
 def test_source_from_method():
     class TestClass(object):
         def test_method(self):
@@ -57,11 +61,13 @@ def test_source_from_method():
     assert source.lines == ["def test_method(self):",
                             "    pass"]
 
+
 def test_source_from_lines():
     lines = ["a \n", "b\n", "c"]
     source = _pytest._code.Source(lines)
     assert source.lines == ['a ', 'b', 'c']
 
+
 def test_source_from_inner_function():
     def f():
         pass
@@ -70,6 +76,7 @@ def test_source_from_inner_function():
     source = _pytest._code.Source(f)
     assert str(source).startswith('def f():')
 
+
 def test_source_putaround_simple():
     source = Source("raise ValueError")
     source = source.putaround(
@@ -78,7 +85,7 @@ def test_source_putaround_simple():
             x = 42
         else:
             x = 23""")
-    assert str(source)=="""\
+    assert str(source) == """\
 try:
     raise ValueError
 except ValueError:
@@ -86,6 +93,7 @@ except ValueError:
 else:
     x = 23"""
 
+
 def test_source_putaround():
     source = Source()
     source = source.putaround("""
@@ -94,24 +102,28 @@ def test_source_putaround():
     """)
     assert str(source).strip() == "if 1:\n    x=1"
 
+
 def test_source_strips():
     source = Source("")
     assert source == Source()
     assert str(source) == ''
     assert source.strip() == source
 
+
 def test_source_strip_multiline():
     source = Source()
     source.lines = ["", " hello", "  "]
     source2 = source.strip()
     assert source2.lines == [" hello"]
 
+
 def test_syntaxerror_rerepresentation():
     ex = pytest.raises(SyntaxError, _pytest._code.compile, 'xyz xyz')
     assert ex.value.lineno == 1
-    assert ex.value.offset in (4,7) # XXX pypy/jython versus cpython?
+    assert ex.value.offset in (4, 7)  # XXX pypy/jython versus cpython?
     assert ex.value.text.strip(), 'x x'
 
+
 def test_isparseable():
     assert Source("hello").isparseable()
     assert Source("if 1:\n  pass").isparseable()
@@ -120,6 +132,7 @@ def test_isparseable():
     assert not Source(" \nif 1:\npass").isparseable()
     assert not Source(chr(0)).isparseable()
 
+
 class TestAccesses(object):
     source = Source("""\
         def f(x):
@@ -127,6 +140,7 @@ class TestAccesses(object):
         def g(x):
             pass
     """)
+
     def test_getrange(self):
         x = self.source[0:2]
         assert x.isparseable()
@@ -144,6 +158,7 @@ class TestAccesses(object):
         l = [x for x in self.source]
         assert len(l) == 4
 
+
 class TestSourceParsingAndCompiling(object):
     source = Source("""\
         def f(x):
@@ -155,12 +170,12 @@ class TestSourceParsingAndCompiling(object):
     def test_compile(self):
         co = _pytest._code.compile("x=3")
         d = {}
-        exec (co, d)
+        exec(co, d)
         assert d['x'] == 3
 
     def test_compile_and_getsource_simple(self):
         co = _pytest._code.compile("x=3")
-        exec (co)
+        exec(co)
         source = _pytest._code.Source(co)
         assert str(source) == "x=3"
 
@@ -181,16 +196,16 @@ class TestSourceParsingAndCompiling(object):
         assert 'ValueError' in source2
 
     def test_getstatement(self):
-        #print str(self.source)
+        # print str(self.source)
         ass = str(self.source[1:])
         for i in range(1, 4):
-            #print "trying start in line %r" % self.source[i]
+            # print "trying start in line %r" % self.source[i]
             s = self.source.getstatement(i)
             #x = s.deindent()
             assert str(s) == ass
 
     def test_getstatementrange_triple_quoted(self):
-        #print str(self.source)
+        # print str(self.source)
         source = Source("""hello('''
         ''')""")
         s = source.getstatement(0)
@@ -211,12 +226,12 @@ class TestSourceParsingAndCompiling(object):
         """)
         assert len(source) == 7
         # check all lineno's that could occur in a traceback
-        #assert source.getstatementrange(0) == (0, 7)
-        #assert source.getstatementrange(1) == (1, 5)
+        # assert source.getstatementrange(0) == (0, 7)
+        # assert source.getstatementrange(1) == (1, 5)
         assert source.getstatementrange(2) == (2, 3)
         assert source.getstatementrange(3) == (3, 4)
         assert source.getstatementrange(4) == (4, 5)
-        #assert source.getstatementrange(5) == (0, 7)
+        # assert source.getstatementrange(5) == (0, 7)
         assert source.getstatementrange(6) == (6, 7)
 
     def test_getstatementrange_bug(self):
@@ -262,7 +277,7 @@ class TestSourceParsingAndCompiling(object):
     def test_getstatementrange_out_of_bounds_py3(self):
         source = Source("if xxx:\n   from .collections import something")
         r = source.getstatementrange(1)
-        assert r == (1,2)
+        assert r == (1, 2)
 
     def test_getstatementrange_with_syntaxerror_issue7(self):
         source = Source(":")
@@ -283,7 +298,7 @@ class TestSourceParsingAndCompiling(object):
         excinfo = pytest.raises(AssertionError, "f(6)")
         frame = excinfo.traceback[-1].frame
         stmt = frame.code.fullsource.getstatement(frame.lineno)
-        #print "block", str(block)
+        # print "block", str(block)
         assert str(stmt).strip().startswith('assert')
 
     @pytest.mark.parametrize('name', ['', None, 'my'])
@@ -291,9 +306,9 @@ class TestSourceParsingAndCompiling(object):
         def check(comp, name):
             co = comp(self.source, name)
             if not name:
-                expected = "codegen %s:%d>" %(mypath, mylineno+2+2)
+                expected = "codegen %s:%d>" % (mypath, mylineno + 2 + 2)
             else:
-                expected = "codegen %r %s:%d>" % (name, mypath, mylineno+2+2)
+                expected = "codegen %r %s:%d>" % (name, mypath, mylineno + 2 + 2)
             fn = co.co_filename
             assert fn.endswith(expected)
 
@@ -307,6 +322,7 @@ class TestSourceParsingAndCompiling(object):
     def test_offsetless_synerr(self):
         pytest.raises(SyntaxError, _pytest._code.compile, "lambda a,a: 0", mode='eval')
 
+
 def test_getstartingblock_singleline():
     class A(object):
         def __init__(self, *args):
@@ -318,19 +334,6 @@ def test_getstartingblock_singleline():
     l = [i for i in x.source.lines if i.strip()]
     assert len(l) == 1
 
-def test_getstartingblock_multiline():
-    class A(object):
-        def __init__(self, *args):
-            frame = sys._getframe(1)
-            self.source = _pytest._code.Frame(frame).statement
-
-    x = A('x',
-          'y' \
-          ,
-          'z')
-
-    l = [i for i in x.source.lines if i.strip()]
-    assert len(l) == 4
 
 def test_getline_finally():
     def c(): pass
@@ -345,6 +348,7 @@ def test_getline_finally():
     source = excinfo.traceback[-1].statement
     assert str(source).strip() == 'c(1)'
 
+
 def test_getfuncsource_dynamic():
     source = """
         def f():
@@ -386,6 +390,7 @@ def test_deindent():
     lines = deindent(source.splitlines())
     assert lines == ['', 'def f():', '    def g():', '        pass', '    ']
 
+
 @pytest.mark.xfail("sys.version_info[:3] < (2,7,0)")
 def test_source_of_class_at_eof_without_newline(tmpdir):
     # this test fails because the implicit inspect.getsource(A) below
@@ -400,10 +405,12 @@ def test_source_of_class_at_eof_without_newline(tmpdir):
     s2 = _pytest._code.Source(tmpdir.join("a.py").pyimport().A)
     assert str(source).strip() == str(s2).strip()
 
+
 if True:
     def x():
         pass
 
+
 def test_getsource_fallback():
     from _pytest._code.source import getsource
     expected = """def x():
@@ -411,6 +418,7 @@ def test_getsource_fallback():
     src = getsource(x)
     assert src == expected
 
+
 def test_idem_compile_and_getsource():
     from _pytest._code.source import getsource
     expected = "def x(): pass"
@@ -418,12 +426,14 @@ def test_idem_compile_and_getsource():
     src = getsource(co)
     assert src == expected
 
+
 def test_findsource_fallback():
     from _pytest._code.source import findsource
     src, lineno = findsource(x)
     assert 'test_findsource_simple' in str(src)
     assert src[lineno] == '    def x():'
 
+
 def test_findsource():
     from _pytest._code.source import findsource
     co = _pytest._code.compile("""if 1:
@@ -450,7 +460,7 @@ def test_getfslineno():
     fspath, lineno = getfslineno(f)
 
     assert fspath.basename == "test_source.py"
-    assert lineno == _pytest._code.getrawcode(f).co_firstlineno - 1 # see findsource
+    assert lineno == _pytest._code.getrawcode(f).co_firstlineno - 1  # see findsource
 
     class A(object):
         pass
@@ -462,15 +472,18 @@ def test_getfslineno():
     assert lineno == A_lineno
 
     assert getfslineno(3) == ("", -1)
+
     class B(object):
         pass
     B.__name__ = "B2"
     assert getfslineno(B)[1] == -1
 
+
 def test_code_of_object_instance_with_call():
     class A(object):
         pass
     pytest.raises(TypeError, lambda: _pytest._code.Source(A()))
+
     class WithCall(object):
         def __call__(self):
             pass
@@ -490,10 +503,12 @@ def getstatement(lineno, source):
     ast, start, end = getstatementrange_ast(lineno, source)
     return source[start:end]
 
+
 def test_oneline():
     source = getstatement(0, "raise ValueError")
     assert str(source) == "raise ValueError"
 
+
 def test_comment_and_no_newline_at_end():
     from _pytest._code.source import getstatementrange_ast
     source = Source(['def test_basic_complex():',
@@ -502,10 +517,12 @@ def test_comment_and_no_newline_at_end():
     ast, start, end = getstatementrange_ast(1, source)
     assert end == 2
 
+
 def test_oneline_and_comment():
     source = getstatement(0, "raise ValueError\n#hello")
     assert str(source) == "raise ValueError"
 
+
 @pytest.mark.xfail(hasattr(sys, "pypy_version_info"),
                    reason='does not work on pypy')
 def test_comments():
@@ -521,29 +538,33 @@ def test_comments():
 comment 4
 """
 '''
-    for line in range(2,6):
+    for line in range(2, 6):
         assert str(getstatement(line, source)) == '    x = 1'
-    for line in range(6,10):
+    for line in range(6, 10):
         assert str(getstatement(line, source)) == '    assert False'
     assert str(getstatement(10, source)) == '"""'
 
+
 def test_comment_in_statement():
     source = '''test(foo=1,
     # comment 1
     bar=2)
 '''
-    for line in range(1,3):
+    for line in range(1, 3):
         assert str(getstatement(line, source)) == \
-               'test(foo=1,\n    # comment 1\n    bar=2)'
+            'test(foo=1,\n    # comment 1\n    bar=2)'
+
 
 def test_single_line_else():
     source = getstatement(1, "if False: 2\nelse: 3")
     assert str(source) == "else: 3"
 
+
 def test_single_line_finally():
     source = getstatement(1, "try: 1\nfinally: 3")
     assert str(source) == "finally: 3"
 
+
 def test_issue55():
     source = ('def round_trip(dinp):\n  assert 1 == dinp\n'
               'def test_rt():\n  round_trip("""\n""")\n')
@@ -560,6 +581,7 @@ x = 3
 """)
     assert str(source) == "raise ValueError(\n    23\n)"
 
+
 class TestTry(object):
     pytestmark = astonly
     source = """\
@@ -587,6 +609,7 @@ else:
         source = getstatement(5, self.source)
         assert str(source) == "    raise KeyError()"
 
+
 class TestTryFinally(object):
     source = """\
 try:
@@ -604,7 +627,6 @@ finally:
         assert str(source) == "    raise IndexError(1)"
 
 
-
 class TestIf(object):
     pytestmark = astonly
     source = """\
@@ -632,6 +654,7 @@ else:
         source = getstatement(5, self.source)
         assert str(source) == "    y = 7"
 
+
 def test_semicolon():
     s = """\
 hello ; pytest.skip()
@@ -639,6 +662,7 @@ hello ; pytest.skip()
     source = getstatement(0, s)
     assert str(source) == s.strip()
 
+
 def test_def_online():
     s = """\
 def func(): raise ValueError(42)
@@ -649,6 +673,7 @@ def something():
     source = getstatement(0, s)
     assert str(source) == "def func(): raise ValueError(42)"
 
+
 def XXX_test_expression_multiline():
     source = """\
 something
