@@ -1,8 +1,10 @@
 from __future__ import absolute_import, division, print_function
-import py, pytest
+import py
+import pytest
 
 # test for _argcomplete but not specific for any application
 
+
 def equal_with_bash(prefix, ffc, fc, out=None):
     res = ffc(prefix)
     res_bash = set(fc(prefix))
@@ -17,10 +19,12 @@ def equal_with_bash(prefix, ffc, fc, out=None):
 # copied from argcomplete.completers as import from there
 # also pulls in argcomplete.__init__ which opens filedescriptor 9
 # this gives an IOError at the end of testrun
+
+
 def _wrapcall(*args, **kargs):
     try:
-        if py.std.sys.version_info > (2,7):
-            return py.std.subprocess.check_output(*args,**kargs).decode().splitlines()
+        if py.std.sys.version_info > (2, 7):
+            return py.std.subprocess.check_output(*args, **kargs).decode().splitlines()
         if 'stdout' in kargs:
             raise ValueError('stdout argument not allowed, it will be overridden.')
         process = py.std.subprocess.Popen(
@@ -36,9 +40,11 @@ def _wrapcall(*args, **kargs):
     except py.std.subprocess.CalledProcessError:
         return []
 
+
 class FilesCompleter(object):
     'File completer class, optionally takes a list of allowed extensions'
-    def __init__(self,allowednames=(),directories=True):
+
+    def __init__(self, allowednames=(), directories=True):
         # Fix if someone passes in a string instead of a list
         if type(allowednames) is str:
             allowednames = [allowednames]
@@ -50,25 +56,26 @@ class FilesCompleter(object):
         completion = []
         if self.allowednames:
             if self.directories:
-                files = _wrapcall(['bash','-c',
-                    "compgen -A directory -- '{p}'".format(p=prefix)])
-                completion += [ f + '/' for f in files]
+                files = _wrapcall(['bash', '-c',
+                                   "compgen -A directory -- '{p}'".format(p=prefix)])
+                completion += [f + '/' for f in files]
             for x in self.allowednames:
                 completion += _wrapcall(['bash', '-c',
-                    "compgen -A file -X '!*.{0}' -- '{p}'".format(x,p=prefix)])
+                                         "compgen -A file -X '!*.{0}' -- '{p}'".format(x, p=prefix)])
         else:
             completion += _wrapcall(['bash', '-c',
-                "compgen -A file -- '{p}'".format(p=prefix)])
+                                     "compgen -A file -- '{p}'".format(p=prefix)])
 
             anticomp = _wrapcall(['bash', '-c',
-                "compgen -A directory -- '{p}'".format(p=prefix)])
+                                  "compgen -A directory -- '{p}'".format(p=prefix)])
 
-            completion = list( set(completion) - set(anticomp))
+            completion = list(set(completion) - set(anticomp))
 
             if self.directories:
                 completion += [f + '/' for f in anticomp]
         return completion
 
+
 class TestArgComplete(object):
     @pytest.mark.skipif("sys.platform in ('win32', 'darwin')")
     def test_compare_with_compgen(self):
