@@ -3,28 +3,30 @@ from _pytest.main import EXIT_NOTESTSCOLLECTED
 import pytest
 import gc
 
+
 def test_simple_unittest(testdir):
     testpath = testdir.makepyfile("""
         import unittest
         class MyTestCase(unittest.TestCase):
             def testpassing(self):
-                self.assertEquals('foo', 'foo')
+                self.assertEqual('foo', 'foo')
             def test_failing(self):
-                self.assertEquals('foo', 'bar')
+                self.assertEqual('foo', 'bar')
     """)
     reprec = testdir.inline_run(testpath)
     assert reprec.matchreport("testpassing").passed
     assert reprec.matchreport("test_failing").failed
 
+
 def test_runTest_method(testdir):
     testdir.makepyfile("""
         import unittest
         class MyTestCaseWithRunTest(unittest.TestCase):
             def runTest(self):
-                self.assertEquals('foo', 'foo')
+                self.assertEqual('foo', 'foo')
         class MyTestCaseWithoutRunTest(unittest.TestCase):
             def runTest(self):
-                self.assertEquals('foo', 'foo')
+                self.assertEqual('foo', 'foo')
             def test_something(self):
                 pass
         """)
@@ -35,6 +37,7 @@ def test_runTest_method(testdir):
         *2 passed*
     """)
 
+
 def test_isclasscheck_issue53(testdir):
     testpath = testdir.makepyfile("""
         import unittest
@@ -46,6 +49,7 @@ def test_isclasscheck_issue53(testdir):
     result = testdir.runpytest(testpath)
     assert result.ret == EXIT_NOTESTSCOLLECTED
 
+
 def test_setup(testdir):
     testpath = testdir.makepyfile("""
         import unittest
@@ -55,7 +59,7 @@ def test_setup(testdir):
             def setup_method(self, method):
                 self.foo2 = 1
             def test_both(self):
-                self.assertEquals(1, self.foo)
+                self.assertEqual(1, self.foo)
                 assert self.foo2 == 1
             def teardown_method(self, method):
                 assert 0, "42"
@@ -66,6 +70,7 @@ def test_setup(testdir):
     rep = reprec.matchreport("test_both", when="teardown")
     assert rep.failed and '42' in str(rep.longrepr)
 
+
 def test_setUpModule(testdir):
     testpath = testdir.makepyfile("""
         l = []
@@ -87,6 +92,7 @@ def test_setUpModule(testdir):
         "*2 passed*",
     ])
 
+
 def test_setUpModule_failing_no_teardown(testdir):
     testpath = testdir.makepyfile("""
         l = []
@@ -105,6 +111,7 @@ def test_setUpModule_failing_no_teardown(testdir):
     call = reprec.getcalls("pytest_runtest_setup")[0]
     assert not call.item.module.l
 
+
 def test_new_instances(testdir):
     testpath = testdir.makepyfile("""
         import unittest
@@ -117,6 +124,7 @@ def test_new_instances(testdir):
     reprec = testdir.inline_run(testpath)
     reprec.assertoutcome(passed=2)
 
+
 def test_teardown(testdir):
     testpath = testdir.makepyfile("""
         import unittest
@@ -128,7 +136,7 @@ def test_teardown(testdir):
                 self.l.append(None)
         class Second(unittest.TestCase):
             def test_check(self):
-                self.assertEquals(MyTestCase.l, [None])
+                self.assertEqual(MyTestCase.l, [None])
     """)
     reprec = testdir.inline_run(testpath)
     passed, skipped, failed = reprec.countoutcomes()
@@ -136,6 +144,7 @@ def test_teardown(testdir):
     assert passed == 2
     assert passed + skipped + failed == 2
 
+
 def test_teardown_issue1649(testdir):
     """
     Are TestCase objects cleaned up? Often unittest TestCase objects set
@@ -158,6 +167,7 @@ def test_teardown_issue1649(testdir):
     for obj in gc.get_objects():
         assert type(obj).__name__ != 'TestCaseObjectsShouldBeCleanedUp'
 
+
 @pytest.mark.skipif("sys.version_info < (2,7)")
 def test_unittest_skip_issue148(testdir):
     testpath = testdir.makepyfile("""
@@ -177,6 +187,7 @@ def test_unittest_skip_issue148(testdir):
     reprec = testdir.inline_run(testpath)
     reprec.assertoutcome(skipped=1)
 
+
 def test_method_and_teardown_failing_reporting(testdir):
     testdir.makepyfile("""
         import unittest, pytest
@@ -196,6 +207,7 @@ def test_method_and_teardown_failing_reporting(testdir):
         "*1 failed*1 error*",
     ])
 
+
 def test_setup_failure_is_shown(testdir):
     testdir.makepyfile("""
         import unittest
@@ -216,6 +228,7 @@ def test_setup_failure_is_shown(testdir):
     ])
     assert 'never42' not in result.stdout.str()
 
+
 def test_setup_setUpClass(testdir):
     testpath = testdir.makepyfile("""
         import unittest
@@ -238,6 +251,7 @@ def test_setup_setUpClass(testdir):
     reprec = testdir.inline_run(testpath)
     reprec.assertoutcome(passed=3)
 
+
 def test_setup_class(testdir):
     testpath = testdir.makepyfile("""
         import unittest
@@ -279,6 +293,7 @@ def test_testcase_adderrorandfailure_defers(testdir, type):
     result = testdir.runpytest()
     assert 'should not raise' not in result.stdout.str()
 
+
 @pytest.mark.parametrize("type", ['Error', 'Failure'])
 def test_testcase_custom_exception_info(testdir, type):
     testdir.makepyfile("""
@@ -310,6 +325,7 @@ def test_testcase_custom_exception_info(testdir, type):
         "*1 failed*",
     ])
 
+
 def test_testcase_totally_incompatible_exception_info(testdir):
     item, = testdir.getitems("""
         from unittest import TestCase
@@ -321,6 +337,7 @@ def test_testcase_totally_incompatible_exception_info(testdir):
     excinfo = item._excinfo.pop(0)
     assert 'ERROR: Unknown Incompatible' in str(excinfo.getrepr())
 
+
 def test_module_level_pytestmark(testdir):
     testpath = testdir.makepyfile("""
         import unittest
@@ -334,61 +351,12 @@ def test_module_level_pytestmark(testdir):
     reprec.assertoutcome(skipped=1)
 
 
-def test_trial_testcase_skip_property(testdir):
-    pytest.importorskip('twisted.trial.unittest')
-    testpath = testdir.makepyfile("""
-        from twisted.trial import unittest
-        class MyTestCase(unittest.TestCase):
-            skip = 'dont run'
-            def test_func(self):
-                pass
-        """)
-    reprec = testdir.inline_run(testpath, "-s")
-    reprec.assertoutcome(skipped=1)
-
-
-def test_trial_testfunction_skip_property(testdir):
-    pytest.importorskip('twisted.trial.unittest')
-    testpath = testdir.makepyfile("""
-        from twisted.trial import unittest
-        class MyTestCase(unittest.TestCase):
-            def test_func(self):
-                pass
-            test_func.skip = 'dont run'
-        """)
-    reprec = testdir.inline_run(testpath, "-s")
-    reprec.assertoutcome(skipped=1)
-
-
-def test_trial_testcase_todo_property(testdir):
-    pytest.importorskip('twisted.trial.unittest')
-    testpath = testdir.makepyfile("""
-        from twisted.trial import unittest
-        class MyTestCase(unittest.TestCase):
-            todo = 'dont run'
-            def test_func(self):
-                assert 0
-        """)
-    reprec = testdir.inline_run(testpath, "-s")
-    reprec.assertoutcome(skipped=1)
-
-
-def test_trial_testfunction_todo_property(testdir):
-    pytest.importorskip('twisted.trial.unittest')
-    testpath = testdir.makepyfile("""
-        from twisted.trial import unittest
-        class MyTestCase(unittest.TestCase):
-            def test_func(self):
-                assert 0
-            test_func.todo = 'dont run'
-        """)
-    reprec = testdir.inline_run(testpath, "-s")
-    reprec.assertoutcome(skipped=1)
-
-
 class TestTrialUnittest(object):
     def setup_class(cls):
         cls.ut = pytest.importorskip("twisted.trial.unittest")
+        # on windows trial uses a socket for a reactor and apparently doesn't close it properly
+        # https://twistedmatrix.com/trac/ticket/9227
+        cls.ignore_unclosed_socket_warning = ('-W', 'always')
 
     def test_trial_testcase_runtest_not_collected(self, testdir):
         testdir.makepyfile("""
@@ -398,7 +366,7 @@ class TestTrialUnittest(object):
                 def test_hello(self):
                     pass
         """)
-        reprec = testdir.inline_run()
+        reprec = testdir.inline_run(*self.ignore_unclosed_socket_warning)
         reprec.assertoutcome(passed=1)
         testdir.makepyfile("""
             from twisted.trial.unittest import TestCase
@@ -407,7 +375,7 @@ class TestTrialUnittest(object):
                 def runTest(self):
                     pass
         """)
-        reprec = testdir.inline_run()
+        reprec = testdir.inline_run(*self.ignore_unclosed_socket_warning)
         reprec.assertoutcome(passed=1)
 
     def test_trial_exceptions_with_skips(self, testdir):
@@ -445,7 +413,7 @@ class TestTrialUnittest(object):
         """)
         from _pytest.compat import _is_unittest_unexpected_success_a_failure
         should_fail = _is_unittest_unexpected_success_a_failure()
-        result = testdir.runpytest("-rxs")
+        result = testdir.runpytest("-rxs", *self.ignore_unclosed_socket_warning)
         result.stdout.fnmatch_lines_random([
             "*XFAIL*test_trial_todo*",
             "*trialselfskip*",
@@ -520,6 +488,51 @@ class TestTrialUnittest(object):
         child.expect("hellopdb")
         child.sendeof()
 
+    def test_trial_testcase_skip_property(self, testdir):
+        testpath = testdir.makepyfile("""
+            from twisted.trial import unittest
+            class MyTestCase(unittest.TestCase):
+                skip = 'dont run'
+                def test_func(self):
+                    pass
+            """)
+        reprec = testdir.inline_run(testpath, "-s")
+        reprec.assertoutcome(skipped=1)
+
+    def test_trial_testfunction_skip_property(self, testdir):
+        testpath = testdir.makepyfile("""
+            from twisted.trial import unittest
+            class MyTestCase(unittest.TestCase):
+                def test_func(self):
+                    pass
+                test_func.skip = 'dont run'
+            """)
+        reprec = testdir.inline_run(testpath, "-s")
+        reprec.assertoutcome(skipped=1)
+
+    def test_trial_testcase_todo_property(self, testdir):
+        testpath = testdir.makepyfile("""
+            from twisted.trial import unittest
+            class MyTestCase(unittest.TestCase):
+                todo = 'dont run'
+                def test_func(self):
+                    assert 0
+            """)
+        reprec = testdir.inline_run(testpath, "-s")
+        reprec.assertoutcome(skipped=1)
+
+    def test_trial_testfunction_todo_property(self, testdir):
+        testpath = testdir.makepyfile("""
+            from twisted.trial import unittest
+            class MyTestCase(unittest.TestCase):
+                def test_func(self):
+                    assert 0
+                test_func.todo = 'dont run'
+            """)
+        reprec = testdir.inline_run(testpath, "-s", *self.ignore_unclosed_socket_warning)
+        reprec.assertoutcome(skipped=1)
+
+
 def test_djangolike_testcase(testdir):
     # contributed from Morten Breekevold
     testdir.makepyfile("""
@@ -580,11 +593,12 @@ def test_unittest_not_shown_in_traceback(testdir):
         class t(unittest.TestCase):
             def test_hello(self):
                 x = 3
-                self.assertEquals(x, 4)
+                self.assertEqual(x, 4)
     """)
     res = testdir.runpytest()
     assert "failUnlessEqual" not in res.stdout.str()
 
+
 def test_unorderable_types(testdir):
     testdir.makepyfile("""
         import unittest
@@ -602,6 +616,7 @@ def test_unorderable_types(testdir):
     assert "TypeError" not in result.stdout.str()
     assert result.ret == EXIT_NOTESTSCOLLECTED
 
+
 def test_unittest_typerror_traceback(testdir):
     testdir.makepyfile("""
         import unittest
@@ -769,6 +784,7 @@ def test_issue333_result_clearing(testdir):
     reprec = testdir.inline_run()
     reprec.assertoutcome(failed=1)
 
+
 @pytest.mark.skipif("sys.version_info < (2,7)")
 def test_unittest_raise_skip_issue748(testdir):
     testdir.makepyfile(test_foo="""
@@ -784,11 +800,12 @@ def test_unittest_raise_skip_issue748(testdir):
         *1 skipped*
     """)
 
+
 @pytest.mark.skipif("sys.version_info < (2,7)")
 def test_unittest_skip_issue1169(testdir):
     testdir.makepyfile(test_foo="""
         import unittest
-        
+
         class MyTestCase(unittest.TestCase):
             @unittest.skip("skipping due to reasons")
             def test_skip(self):
@@ -800,6 +817,7 @@ def test_unittest_skip_issue1169(testdir):
         *1 skipped*
     """)
 
+
 def test_class_method_containing_test_issue1558(testdir):
     testdir.makepyfile(test_foo="""
         import unittest
